package	jp.co.sds_corp.util.daemon;

import java.util.Iterator;
import java.util.List;
import java.util.Vector;

import jp.co.sds_corp.util.config.IConfiguration;
import jp.co.sds_corp.util.daemon.config.ConfigUtility;
import jp.co.sds_corp.util.log.CmnLogFactory;
import jp.co.sds_corp.util.log.CmnLogger;

/**
* 複数のサービスを起動する親サービスの抽象クラスです。
*/
public abstract class NestedService extends AbstractService
{
	static final CmnLogger logger = CmnLogFactory.getLogger();
	Vector<IService>	vecSvc = new Vector<IService>();

	/**
	* このサービスに属する子サービスの一覧を返します。
	* @return	このサービスに属する子サービスの一覧
	*/
	public Iterator<IService> getChildServices() {
		return vecSvc.iterator();
	}

	/**
	* デフォルトの初期処理.
	* サービスをロードし、サービスの初期化を行う
	*/
	public void init( IConfiguration config )
		throws Exception
	{
		super.init( config );
		Iterator<IConfiguration> itr = config.getChilds( "Service" );
		while ( itr.hasNext()) {
			IConfiguration cfg = (IConfiguration )itr.next();
			IService svc = createService( cfg );
			svc.init( cfg );
			vecSvc.add( svc );
		}
	}

	protected IService createService( IConfiguration config ) throws Exception {
		IService svc = (IService )ConfigUtility.createInstance( config );
		String name = config.getAttributes().get( "name" );
		svc.setName( name );
		logger.debug( this, "loading nested service:" + svc );
		return svc;
	}

	/**
	* サービスを開始します。
	*/
	public abstract void start();
	/**
	* サービスを終了します。
	*/
	public abstract void stop();

	/**
	* 登録された全てのサービスを返します。
	* @return	登録された全てのサービス
	*/
	public List<IService> getServices() {
		return vecSvc;
	}

	/**
	* このサービスの子サービスも含めた文字列表現を返します。
	* @return	文字列表現
	*/
	public String toString() {
		String ret = getName() + "," + getClass().getName();
		for ( int i = 0; i < vecSvc.size(); i++ ) {
			IService svc = (IService )vecSvc.get( i );
			ret += "\n\t" + svc.toString();
		}
		return ret;
	}

	/**
	* 設定されている内容をXML形式で出力します。
	* @param	config	設定情報
	*/
	public void saveConfig( IConfiguration config ) {
		super.saveConfig( config );
		for ( int i = 0; i < vecSvc.size(); i++ ) {
			IService svc = (IService )vecSvc.get( i );
			IConfiguration c = config.addChild( "Service" );
			svc.saveConfig( c );
		}
	}
}

