package	jp.co.sds_corp.util.daemon.file;

import java.io.File;
import java.util.Iterator;
import java.util.Vector;

import jp.co.sds_corp.util.config.IConfiguration;

/**
* ファイル名フィルタです。
<P>
{@link #init}で使用されるXMLは以下の形式です。
<PRE>
&lt;Filter class="jp.co.sds_corp.util.daemon.file.SimpleFilenameFilter"&gt;
	&lt;file&gt;foo.txt&lt;/file&gt;
	&lt;file&gt;bar.dat&lt;/file&gt;
&lt;/Filter&gt;
</PRE>
*/
public class SimpleFilenameFilter implements IFilenameFilter
{
	Vector<String>	vecFile = new Vector<String>();

	/**
	* 設定情報から正規表現のパターンを取得し、初期化します。
	* @param	config	設定情報
	*/
	public void init( IConfiguration config ) throws Exception {
		Iterator<IConfiguration> itr = config.getChilds( "file" );
		while ( itr.hasNext()) {
			IConfiguration c = itr.next();
			String file = c.get();
			vecFile.add( file );
		}
	}

	/**
	* 指定されたファイルをファイルリストに含めるかどうかをテストします。
	* @param	path	ファイルが見つかったディレクトリ
	* @param	name	ファイルの名前
	*/
	public boolean accept( File path, String name ) {
		for ( int i = 0; i < vecFile.size(); i++ ) {
			if ( name.equals( vecFile.get( i )) ) {
				return true;
			}
		}
		return false;
	}

	/**
	* 設定されている内容をXML形式で出力します。
	* @param	config	設定情報
	*/
	public void saveConfig( IConfiguration config ) {
		config.setAttribute( "class", getClass().getName() );
		for ( int i = 0; i < vecFile.size(); i++ ) {
			config.addChild( "file", vecFile.get( i ) );
		}
	}

	/**
	* このファイル名フィルタの文字列表現を返します。
	* @return	このファイル名フィルタの文字列表現
	*/
	public String toString() {
		String ret = getClass().getName() + "[";
		for ( int i = 0; i < vecFile.size(); i++ ) {
			if ( i > 0 ) {
				ret += ",";
			}
			ret += vecFile.get( i );
		}
		return ret;
	}
}
